@@ -1,5 +1,7 @@
 use std::convert::TryFrom;
 
+#[cfg(feature = "object")]
+use crate::chunked_array::object::extension::polars_extension::PolarsExtension;
 use crate::prelude::*;
 
 #[inline]
@@ -100,8 +102,13 @@ pub(crate) unsafe fn arr_to_any_value<'a>(
             AnyValue::Time(v)
         }
         #[cfg(feature = "object")]
-        DataType::Object(_) => panic!("should not be here"),
-        dt => panic!("not implemented for {:?}", dt),
+        DataType::Object(_) => {
+            // We should almost never hit this. The only known exception is when we put objects in
+            // structs. Any other hit should be considered a bug.
+            let arr = &*(arr as *const dyn Array as *const FixedSizeBinaryArray);
+            PolarsExtension::arr_to_av(arr, idx)
+        }
+        dt => panic!("not implemented for {dt:?}"),
     }
 }
 
@@ -148,10 +155,14 @@ macro_rules! get_any_value {
     ($self:ident, $index:expr) => {{
         let (chunk_idx, idx) = $self.index_to_chunked_index($index);
         let arr = &*$self.chunks[chunk_idx];
-        assert!(idx < arr.len());
-        // SAFETY
-        // bounds are checked
-        unsafe { arr_to_any_value(arr, idx, $self.dtype()) }
+
+        if idx < arr.len() {
+            // SAFETY
+            // bounds are checked
+            Ok(unsafe { arr_to_any_value(arr, idx, $self.dtype()) })
+        } else {
+            Err(PolarsError::ComputeError("index is out of bounds".into()))
+        }
     }};
 }
 
@@ -164,7 +175,7 @@ where
         get_any_value_unchecked!(self, index)
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         get_any_value!(self, index)
     }
 }
@@ -175,7 +186,7 @@ impl ChunkAnyValue for BooleanChunked {
         get_any_value_unchecked!(self, index)
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         get_any_value!(self, index)
     }
 }
@@ -186,7 +197,7 @@ impl ChunkAnyValue for Utf8Chunked {
         get_any_value_unchecked!(self, index)
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         get_any_value!(self, index)
     }
 }
@@ -198,7 +209,7 @@ impl ChunkAnyValue for BinaryChunked {
         get_any_value_unchecked!(self, index)
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         get_any_value!(self, index)
     }
 }
@@ -209,7 +220,7 @@ impl ChunkAnyValue for ListChunked {
         get_any_value_unchecked!(self, index)
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         get_any_value!(self, index)
     }
 }
@@ -224,10 +235,10 @@ impl<T: PolarsObject> ChunkAnyValue for ObjectChunked<T> {
         }
     }
 
-    fn get_any_value(&self, index: usize) -> AnyValue {
+    fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue> {
         match self.get_object(index) {
-            None => AnyValue::Null,
-            Some(v) => AnyValue::Object(v),
+            None => Err(PolarsError::ComputeError("index is out of bounds".into())),
+            Some(v) => Ok(AnyValue::Object(v)),
         }
     }
 }
