@@ -3,6 +3,17 @@ use polars_utils::unwrap::UnwrapUncheckedRelease;
 
 use super::*;
 
+#[cfg(feature = "object")]
+#[derive(Debug)]
+pub struct OwnedObject(pub Box<dyn PolarsObjectSafe>);
+
+#[cfg(feature = "object")]
+impl Clone for OwnedObject {
+    fn clone(&self) -> Self {
+        Self(self.0.to_boxed())
+    }
+}
+
 #[derive(Debug, Clone)]
 pub enum AnyValue<'a> {
     Null,
@@ -50,7 +61,10 @@ pub enum AnyValue<'a> {
     List(Series),
     #[cfg(feature = "object")]
     /// Can be used to fmt and implements Any, so can be downcasted to the proper value type.
+    #[cfg(feature = "object")]
     Object(&'a dyn PolarsObjectSafe),
+    #[cfg(feature = "object")]
+    ObjectOwned(OwnedObject),
     #[cfg(feature = "dtype-struct")]
     // 3 pointers and thus not larger than string/vec
     Struct(usize, &'a StructArray, &'a [Field]),
@@ -160,7 +174,7 @@ impl<'a> Deserialize<'a> for AnyValue<'static> {
             type Value = AvField;
 
             fn expecting(&self, formatter: &mut Formatter) -> std::fmt::Result {
-                write!(formatter, "an integer between 0-{}", LAST)
+                write!(formatter, "an integer between 0-{LAST}")
             }
 
             fn visit_i64<E>(self, v: i64) -> std::result::Result<Self::Value, E>
@@ -387,7 +401,7 @@ impl<'a> AnyValue<'a> {
                     NumCast::from(0)
                 }
             }
-            dt => panic!("dtype {:?} not implemented", dt),
+            dt => panic!("dtype {dt:?} not implemented"),
         }
     }
 
@@ -461,7 +475,7 @@ impl<'a> AnyValue<'a> {
             #[cfg(feature = "dtype-date")]
             AnyValue::Int32(v) => AnyValue::Date(v),
             AnyValue::Null => AnyValue::Null,
-            dt => panic!("cannot create date from other type. dtype: {}", dt),
+            dt => panic!("cannot create date from other type. dtype: {dt}"),
         }
     }
     #[cfg(feature = "dtype-datetime")]
@@ -469,7 +483,7 @@ impl<'a> AnyValue<'a> {
         match self {
             AnyValue::Int64(v) => AnyValue::Datetime(v, tu, tz),
             AnyValue::Null => AnyValue::Null,
-            dt => panic!("cannot create date from other type. dtype: {}", dt),
+            dt => panic!("cannot create date from other type. dtype: {dt}"),
         }
     }
 
@@ -478,7 +492,7 @@ impl<'a> AnyValue<'a> {
         match self {
             AnyValue::Int64(v) => AnyValue::Duration(v, tu),
             AnyValue::Null => AnyValue::Null,
-            dt => panic!("cannot create date from other type. dtype: {}", dt),
+            dt => panic!("cannot create date from other type. dtype: {dt}"),
         }
     }
 
@@ -487,7 +501,7 @@ impl<'a> AnyValue<'a> {
         match self {
             AnyValue::Int64(v) => AnyValue::Time(v),
             AnyValue::Null => AnyValue::Null,
-            dt => panic!("cannot create date from other type. dtype: {}", dt),
+            dt => panic!("cannot create date from other type. dtype: {dt}"),
         }
     }
 
@@ -546,9 +560,11 @@ impl<'a> AnyValue<'a> {
             Binary(v) => BinaryOwned(v.to_vec()),
             #[cfg(feature = "dtype-binary")]
             BinaryOwned(v) => BinaryOwned(v),
+            #[cfg(feature = "object")]
+            Object(v) => ObjectOwned(OwnedObject(v.to_boxed())),
             dt => {
                 return Err(PolarsError::ComputeError(
-                    format!("cannot get static AnyValue from {}", dt).into(),
+                    format!("cannot get static AnyValue from {dt}").into(),
                 ))
             }
         };
