@@ -178,9 +178,9 @@ impl Series {
         &mut *chunks
     }
 
-    pub fn set_sorted(&mut self, sorted: IsSorted) {
+    pub fn set_sorted_flag(&mut self, sorted: IsSorted) {
         let inner = self._get_inner_mut();
-        inner._set_sorted(sorted)
+        inner._set_sorted_flag(sorted)
     }
 
     pub fn into_frame(self) -> DataFrame {
@@ -228,7 +228,12 @@ impl Series {
 
     /// Cast `[Series]` to another `[DataType]`
     pub fn cast(&self, dtype: &DataType) -> PolarsResult<Self> {
-        self.0.cast(dtype)
+        let len = self.len();
+        if self.null_count() == len {
+            Ok(Series::full_null(self.name(), len, dtype))
+        } else {
+            self.0.cast(dtype)
+        }
     }
 
     /// Compute the sum of all values in this Series.
