@@ -1,8 +1,6 @@
 mod expr;
 mod lp;
 
-pub use expr::*;
+pub(crate) use expr::*;
 pub use lp::*;
 use polars_plan::prelude::*;
-
-use super::expressions::*;
