@@ -1,5 +1,9 @@
 pub(crate) use polars_ops::prelude::*;
-pub use polars_plan::logical_plan::{Literal, LiteralValue, LogicalPlan, Null, NULL};
+pub use polars_plan::logical_plan::{
+    AnonymousScan, AnonymousScanOptions, Literal, LiteralValue, LogicalPlan, Null, NULL,
+};
+#[cfg(feature = "parquet")]
+pub use polars_plan::prelude::ParquetWriteOptions;
 pub(crate) use polars_plan::prelude::*;
 #[cfg(feature = "rolling_window")]
 pub use polars_time::{prelude::RollingOptions, Duration};
