@@ -1,7 +1,12 @@
+#[cfg(feature = "extract_jsonpath")]
+#[cfg_attr(docsrs, doc(cfg(feature = "extract_jsonpath")))]
+mod json_path;
 #[cfg(feature = "strings")]
 #[cfg_attr(docsrs, doc(cfg(feature = "strings")))]
 mod namespace;
 
+#[cfg(feature = "extract_jsonpath")]
+pub use json_path::*;
 #[cfg(feature = "strings")]
 pub use namespace::*;
 use polars_core::prelude::*;
