@@ -47,7 +47,11 @@ pub(super) fn slice(args: &mut [Series]) -> PolarsResult<Series> {
     let mut out: ListChunked = match (offset_s.len(), length_s.len()) {
         (1, 1) => {
             let offset = offset_s.get(0).unwrap().try_extract::<i64>()?;
-            let slice_len = length_s.get(0).unwrap().try_extract::<usize>()?;
+            let slice_len = length_s
+                .get(0)
+                .unwrap()
+                .extract::<usize>()
+                .unwrap_or(usize::MAX);
             return Ok(list_ca.lst_slice(offset, slice_len).into_series());
         }
         (1, length_slice_len) => {
@@ -73,7 +77,11 @@ pub(super) fn slice(args: &mut [Series]) -> PolarsResult<Series> {
             if offset_len != list_ca.len() {
                 return Err(PolarsError::ComputeError("the length of the slice 'offset' argument does not match that of the list column".into()));
             }
-            let length_slice = length_s.get(0).unwrap().try_extract::<usize>()?;
+            let length_slice = length_s
+                .get(0)
+                .unwrap()
+                .extract::<usize>()
+                .unwrap_or(usize::MAX);
             let offset_ca = offset_s.cast(&DataType::Int64)?;
             let offset_ca = offset_ca.i64().unwrap();
             list_ca
