@@ -99,7 +99,7 @@ impl FunctionExpr {
                     Ok(DataType::Datetime(*tu, Some(tz.clone())))
                 } else {
                     Err(PolarsError::SchemaMisMatch(
-                        format!("expected Datetime got {:?}", dt).into(),
+                        format!("expected Datetime got {dt:?}").into(),
                     ))
                 }
             })
@@ -139,6 +139,13 @@ impl FunctionExpr {
                     }
                 }
             }
+            #[cfg(feature = "dtype-binary")]
+            BinaryExpr(s) => {
+                use BinaryFunction::*;
+                match s {
+                    Contains { .. } | EndsWith(_) | StartsWith(_) => with_dtype(DataType::Boolean),
+                }
+            }
             #[cfg(feature = "temporal")]
             TemporalExpr(fun) => {
                 use TemporalFunction::*;
