@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, Sequence
+from typing import Any, Callable, Sequence
 
 from polars.datatypes import (
+    DTYPE_TEMPORAL_UNITS,
     Boolean,
     Categorical,
     Date,
@@ -24,6 +25,7 @@ from polars.datatypes import (
     Utf8,
     _base_type,
 )
+from polars.dependencies import numpy as np
 
 try:
     from polars.polars import PySeries
@@ -32,9 +34,6 @@ try:
 except ImportError:
     _DOCUMENTING = True
 
-if TYPE_CHECKING:
-    import numpy as np
-
 
 if not _DOCUMENTING:
     _POLARS_TYPE_TO_CONSTRUCTOR: dict[
@@ -76,8 +75,6 @@ _NUMPY_TYPE_TO_CONSTRUCTOR = None
 
 
 def _set_numpy_to_constructor() -> None:
-    import numpy as np
-
     global _NUMPY_TYPE_TO_CONSTRUCTOR
     _NUMPY_TYPE_TO_CONSTRUCTOR = {
         np.float32: PySeries.new_f32,
@@ -96,6 +93,22 @@ def _set_numpy_to_constructor() -> None:
     }
 
 
+def numpy_values_and_dtype(
+    values: np.ndarray[Any, Any]
+) -> tuple[np.ndarray[Any, Any], type]:
+    """Return numpy values and their associated dtype, adjusting if required."""
+    dtype = values.dtype.type
+    if dtype == np.float16:
+        values = values.astype(np.float32)
+        dtype = values.dtype.type
+    elif dtype == np.datetime64:
+        if np.datetime_data(values.dtype)[0] in DTYPE_TEMPORAL_UNITS:
+            values = values.astype(np.int64)
+        else:
+            dtype = object
+    return values, dtype
+
+
 def numpy_type_to_constructor(dtype: type[np.dtype[Any]]) -> Callable[..., PySeries]:
     """Get the right PySeries constructor for the given Polars dtype."""
     if _NUMPY_TYPE_TO_CONSTRUCTOR is None:
