@@ -1,14 +1,20 @@
 from __future__ import annotations
 
 import warnings
+from datetime import timedelta
 from typing import TYPE_CHECKING, Any, Callable, Generic, Iterable, Sequence, TypeVar
 
 import polars.internals as pli
 from polars.internals.dataframe.pivot import PivotOps
+from polars.utils import _timedelta_to_pl_duration
 
 if TYPE_CHECKING:
     from polars.datatypes import DataType
-    from polars.internals.type_aliases import ClosedWindow, InterpolationMethod
+    from polars.internals.type_aliases import (
+        ClosedWindow,
+        RollingInterpolationMethod,
+        StartBy,
+    )
     from polars.polars import PyDataFrame
 
 # A type variable used to refer to a polars.DataFrame or any subclass of it.
@@ -296,7 +302,7 @@ class GroupBy(Generic[DF]):
             .lazy()
             .groupby(self.by, maintain_order=self.maintain_order)
             .agg(aggs)
-            .collect(no_optimization=True, string_cache=False)
+            .collect(no_optimization=True)
         )
         return self._dataframe_class._from_pydf(df._df)
 
@@ -360,7 +366,7 @@ class GroupBy(Generic[DF]):
             .lazy()
             .groupby(self.by, self.maintain_order)
             .head(n)
-            .collect(no_optimization=True, string_cache=False)
+            .collect(no_optimization=True)
         )
         return self._dataframe_class._from_pydf(df._df)
 
@@ -424,7 +430,7 @@ class GroupBy(Generic[DF]):
             .lazy()
             .groupby(self.by, self.maintain_order)
             .tail(n)
-            .collect(no_optimization=True, string_cache=False)
+            .collect(no_optimization=True)
         )
         return self._dataframe_class._from_pydf(df._df)
 
@@ -594,17 +600,17 @@ class GroupBy(Generic[DF]):
         ... )
         >>> df.groupby("d", maintain_order=True).min()
         shape: (3, 4)
-        ┌────────┬─────┬──────┬─────┐
-        │ d      ┆ a   ┆ b    ┆ c   │
-        │ ---    ┆ --- ┆ ---  ┆ --- │
-        │ str    ┆ i64 ┆ f64  ┆ u32 │
-        ╞════════╪═════╪══════╪═════╡
-        │ Apple  ┆ 1   ┆ 0.5  ┆ 0   │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌┤
-        │ Orange ┆ 2   ┆ 0.5  ┆ 1   │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌┤
-        │ Banana ┆ 4   ┆ 13.0 ┆ 0   │
-        └────────┴─────┴──────┴─────┘
+        ┌────────┬─────┬──────┬───────┐
+        │ d      ┆ a   ┆ b    ┆ c     │
+        │ ---    ┆ --- ┆ ---  ┆ ---   │
+        │ str    ┆ i64 ┆ f64  ┆ bool  │
+        ╞════════╪═════╪══════╪═══════╡
+        │ Apple  ┆ 1   ┆ 0.5  ┆ false │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
+        │ Orange ┆ 2   ┆ 0.5  ┆ true  │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
+        │ Banana ┆ 4   ┆ 13.0 ┆ false │
+        └────────┴─────┴──────┴───────┘
 
         """
         return self.agg(pli.all().min())
@@ -625,17 +631,17 @@ class GroupBy(Generic[DF]):
         ... )
         >>> df.groupby("d", maintain_order=True).max()
         shape: (3, 4)
-        ┌────────┬─────┬──────┬─────┐
-        │ d      ┆ a   ┆ b    ┆ c   │
-        │ ---    ┆ --- ┆ ---  ┆ --- │
-        │ str    ┆ i64 ┆ f64  ┆ u32 │
-        ╞════════╪═════╪══════╪═════╡
-        │ Apple  ┆ 3   ┆ 10.0 ┆ 1   │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌┤
-        │ Orange ┆ 2   ┆ 0.5  ┆ 1   │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌┤
-        │ Banana ┆ 5   ┆ 14.0 ┆ 1   │
-        └────────┴─────┴──────┴─────┘
+        ┌────────┬─────┬──────┬──────┐
+        │ d      ┆ a   ┆ b    ┆ c    │
+        │ ---    ┆ --- ┆ ---  ┆ ---  │
+        │ str    ┆ i64 ┆ f64  ┆ bool │
+        ╞════════╪═════╪══════╪══════╡
+        │ Apple  ┆ 3   ┆ 10.0 ┆ true │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
+        │ Orange ┆ 2   ┆ 0.5  ┆ true │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
+        │ Banana ┆ 5   ┆ 14.0 ┆ true │
+        └────────┴─────┴──────┴──────┘
 
         """
         return self.agg(pli.all().max())
@@ -688,17 +694,17 @@ class GroupBy(Generic[DF]):
 
         >>> df.groupby("d", maintain_order=True).mean()
         shape: (3, 4)
-        ┌────────┬─────┬──────────┬──────┐
-        │ d      ┆ a   ┆ b        ┆ c    │
-        │ ---    ┆ --- ┆ ---      ┆ ---  │
-        │ str    ┆ f64 ┆ f64      ┆ bool │
-        ╞════════╪═════╪══════════╪══════╡
-        │ Apple  ┆ 2.0 ┆ 4.833333 ┆ null │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┤
-        │ Orange ┆ 2.0 ┆ 0.5      ┆ null │
-        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┤
-        │ Banana ┆ 4.5 ┆ 13.5     ┆ null │
-        └────────┴─────┴──────────┴──────┘
+        ┌────────┬─────┬──────────┬──────────┐
+        │ d      ┆ a   ┆ b        ┆ c        │
+        │ ---    ┆ --- ┆ ---      ┆ ---      │
+        │ str    ┆ f64 ┆ f64      ┆ f64      │
+        ╞════════╪═════╪══════════╪══════════╡
+        │ Apple  ┆ 2.0 ┆ 4.833333 ┆ 0.666667 │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤
+        │ Orange ┆ 2.0 ┆ 0.5      ┆ 1.0      │
+        ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌┤
+        │ Banana ┆ 4.5 ┆ 13.5     ┆ 0.5      │
+        └────────┴─────┴──────────┴──────────┘
 
         """
         return self.agg(pli.all().mean())
@@ -733,7 +739,7 @@ class GroupBy(Generic[DF]):
         return self.agg(pli.all().n_unique())
 
     def quantile(
-        self, quantile: float, interpolation: InterpolationMethod = "nearest"
+        self, quantile: float, interpolation: RollingInterpolationMethod = "nearest"
     ) -> pli.DataFrame:
         """
         Compute the quantile per group.
@@ -834,11 +840,14 @@ class RollingGroupBy(Generic[DF]):
         self,
         df: DF,
         index_column: str,
-        period: str,
-        offset: str | None,
+        period: str | timedelta,
+        offset: str | timedelta | None,
         closed: ClosedWindow = "none",
         by: str | Sequence[str] | pli.Expr | Sequence[pli.Expr] | None = None,
     ):
+        period = _timedelta_to_pl_duration(period)
+        offset = _timedelta_to_pl_duration(offset)
+
         self.df = df
         self.time_column = index_column
         self.period = period
@@ -850,10 +859,14 @@ class RollingGroupBy(Generic[DF]):
         return (
             self.df.lazy()
             .groupby_rolling(
-                self.time_column, self.period, self.offset, self.closed, self.by
+                index_column=self.time_column,
+                period=self.period,
+                offset=self.offset,
+                closed=self.closed,
+                by=self.by,
             )
             .agg(aggs)
-            .collect(no_optimization=True, string_cache=False)
+            .collect(no_optimization=True)
         )
 
 
@@ -861,7 +874,7 @@ class DynamicGroupBy(Generic[DF]):
     """
     A dynamic grouper.
 
-    This has an `.agg` method which will allow you to run all polars expressions in a
+    This has an `.agg` method which allows you to run all polars expressions in a
     groupby context.
     """
 
@@ -869,14 +882,20 @@ class DynamicGroupBy(Generic[DF]):
         self,
         df: DF,
         index_column: str,
-        every: str,
-        period: str | None,
-        offset: str | None,
+        every: str | timedelta,
+        period: str | timedelta | None,
+        offset: str | timedelta | None,
         truncate: bool = True,
         include_boundaries: bool = True,
         closed: ClosedWindow = "none",
         by: str | Sequence[str] | pli.Expr | Sequence[pli.Expr] | None = None,
+        start_by: StartBy = "window",
     ):
+
+        period = _timedelta_to_pl_duration(period)
+        offset = _timedelta_to_pl_duration(offset)
+        every = _timedelta_to_pl_duration(every)
+
         self.df = df
         self.time_column = index_column
         self.every = every
@@ -886,22 +905,24 @@ class DynamicGroupBy(Generic[DF]):
         self.include_boundaries = include_boundaries
         self.closed = closed
         self.by = by
+        self.start_by = start_by
 
     def agg(self, aggs: pli.Expr | Sequence[pli.Expr]) -> pli.DataFrame:
         return (
             self.df.lazy()
             .groupby_dynamic(
-                self.time_column,
-                self.every,
-                self.period,
-                self.offset,
-                self.truncate,
-                self.include_boundaries,
-                self.closed,
-                self.by,
+                index_column=self.time_column,
+                every=self.every,
+                period=self.period,
+                offset=self.offset,
+                truncate=self.truncate,
+                include_boundaries=self.include_boundaries,
+                closed=self.closed,
+                by=self.by,
+                start_by=self.start_by,
             )
             .agg(aggs)
-            .collect(no_optimization=True, string_cache=False)
+            .collect(no_optimization=True)
         )
 
 
@@ -994,7 +1015,7 @@ class GBSelection(Generic[DF]):
         )
 
     def quantile(
-        self, quantile: float, interpolation: InterpolationMethod = "nearest"
+        self, quantile: float, interpolation: RollingInterpolationMethod = "nearest"
     ) -> DF:
         """
         Compute the quantile per group.
