@@ -48,7 +48,7 @@ class ExprDateTimeNameSpace:
         1m   # 1 minute
         1h   # 1 hour
         1d   # 1 day
-        1w   # 1 week
+        1w   # 1 calendar week starting at Monday
         1mo  # 1 calendar month
         1y   # 1 calendar year
 
@@ -181,7 +181,7 @@ class ExprDateTimeNameSpace:
         1m   # 1 minute
         1h   # 1 hour
         1d   # 1 day
-        1w   # 1 week
+        1w   # 1 calendar week
         1mo  # 1 calendar month
         1y   # 1 calendar year
 
@@ -517,7 +517,7 @@ class ExprDateTimeNameSpace:
 
         Applies to Date and Datetime columns.
 
-        Returns the weekday number where monday = 0 and sunday = 6
+        Returns the ISO weekday number where monday = 1 and sunday = 7
 
         Returns
         -------
@@ -555,11 +555,11 @@ class ExprDateTimeNameSpace:
         │ ---     ┆ ---          ┆ ---         │
         │ u32     ┆ u32          ┆ u32         │
         ╞═════════╪══════════════╪═════════════╡
-        │ 0       ┆ 1            ┆ 1           │
+        │ 1       ┆ 1            ┆ 1           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 3       ┆ 4            ┆ 4           │
+        │ 4       ┆ 4            ┆ 4           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 6       ┆ 7            ┆ 7           │
+        │ 7       ┆ 7            ┆ 7           │
         └─────────┴──────────────┴─────────────┘
 
         """
@@ -610,11 +610,11 @@ class ExprDateTimeNameSpace:
         │ ---     ┆ ---          ┆ ---         │
         │ u32     ┆ u32          ┆ u32         │
         ╞═════════╪══════════════╪═════════════╡
-        │ 0       ┆ 1            ┆ 1           │
+        │ 1       ┆ 1            ┆ 1           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 3       ┆ 4            ┆ 4           │
+        │ 4       ┆ 4            ┆ 4           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 6       ┆ 7            ┆ 7           │
+        │ 7       ┆ 7            ┆ 7           │
         └─────────┴──────────────┴─────────────┘
 
         """
@@ -665,11 +665,11 @@ class ExprDateTimeNameSpace:
         │ ---     ┆ ---          ┆ ---         │
         │ u32     ┆ u32          ┆ u32         │
         ╞═════════╪══════════════╪═════════════╡
-        │ 0       ┆ 1            ┆ 1           │
+        │ 1       ┆ 1            ┆ 1           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 3       ┆ 4            ┆ 4           │
+        │ 4       ┆ 4            ┆ 4           │
         ├╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
-        │ 6       ┆ 7            ┆ 7           │
+        │ 7       ┆ 7            ┆ 7           │
         └─────────┴──────────────┴─────────────┘
 
         """
