@@ -7,7 +7,7 @@ from polars.datatypes import (
     DataType,
     Date,
     Datetime,
-    TemporalDataType,
+    PolarsTemporalType,
     Time,
     is_polars_dtype,
 )
@@ -27,7 +27,7 @@ class ExprStringNameSpace:
 
     def strptime(
         self,
-        datatype: TemporalDataType,
+        datatype: PolarsTemporalType,
         fmt: str | None = None,
         strict: bool = True,
         exact: bool = True,
@@ -263,92 +263,136 @@ class ExprStringNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.str_to_lowercase())
 
-    def strip(self, matches: None | str = None) -> pli.Expr:
-        """
-        Remove leading and trailing whitespace.
+    def strip(self, matches: str | None = None) -> pli.Expr:
+        r"""
+        Remove leading and trailing characters.
 
         Parameters
         ----------
         matches
-            An optional single character that should be trimmed
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
 
         Examples
         --------
-        >>> df = pl.DataFrame({"foo": [" lead", "trail ", " both "]})
+        >>> df = pl.DataFrame({"foo": [" hello ", "\tworld"]})
         >>> df.select(pl.col("foo").str.strip())
-        shape: (3, 1)
+        shape: (2, 1)
         ┌───────┐
         │ foo   │
         │ ---   │
         │ str   │
         ╞═══════╡
-        │ lead  │
+        │ hello │
         ├╌╌╌╌╌╌╌┤
-        │ trail │
-        ├╌╌╌╌╌╌╌┤
-        │ both  │
+        │ world │
         └───────┘
 
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> df.select(pl.col("foo").str.strip("od\t"))
+        shape: (2, 1)
+        ┌─────────┐
+        │ foo     │
+        │ ---     │
+        │ str     │
+        ╞═════════╡
+        │  hello  │
+        ├╌╌╌╌╌╌╌╌╌┤
+        │ worl    │
+        └─────────┘
+
         """
-        if matches is not None and len(matches) > 1:
-            raise ValueError("matches should contain a single character")
         return pli.wrap_expr(self._pyexpr.str_strip(matches))
 
-    def lstrip(self, matches: None | str = None) -> pli.Expr:
-        """
-        Remove leading whitespace.
+    def lstrip(self, matches: str | None = None) -> pli.Expr:
+        r"""
+        Remove leading characters.
+
+        Parameters
+        ----------
+        matches
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
 
         Examples
         --------
-        >>> df = pl.DataFrame({"foo": [" lead", "trail ", " both "]})
+        >>> df = pl.DataFrame({"foo": [" hello ", "\tworld"]})
         >>> df.select(pl.col("foo").str.lstrip())
-        shape: (3, 1)
+        shape: (2, 1)
         ┌────────┐
         │ foo    │
         │ ---    │
         │ str    │
         ╞════════╡
-        │ lead   │
+        │ hello  │
         ├╌╌╌╌╌╌╌╌┤
-        │ trail  │
-        ├╌╌╌╌╌╌╌╌┤
-        │ both   │
+        │ world  │
         └────────┘
 
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> df.select(pl.col("foo").str.lstrip("wod\t"))
+        shape: (2, 1)
+        ┌─────────┐
+        │ foo     │
+        │ ---     │
+        │ str     │
+        ╞═════════╡
+        │  hello  │
+        ├╌╌╌╌╌╌╌╌╌┤
+        │ rld     │
+        └─────────┘
+
         """
-        if matches is not None and len(matches) > 1:
-            raise ValueError("matches should contain a single character")
         return pli.wrap_expr(self._pyexpr.str_lstrip(matches))
 
-    def rstrip(self, matches: None | str = None) -> pli.Expr:
-        """
-        Remove trailing whitespace.
+    def rstrip(self, matches: str | None = None) -> pli.Expr:
+        r"""
+        Remove trailing characters.
 
         Parameters
         ----------
         matches
-            An optional single character that should be trimmed
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
 
         Examples
         --------
-        >>> df = pl.DataFrame({"foo": [" lead", "trail ", " both "]})
+        >>> df = pl.DataFrame({"foo": [" hello ", "world\t"]})
         >>> df.select(pl.col("foo").str.rstrip())
-        shape: (3, 1)
-        ┌───────┐
-        │ foo   │
-        │ ---   │
-        │ str   │
-        ╞═══════╡
-        │  lead │
-        ├╌╌╌╌╌╌╌┤
-        │ trail │
-        ├╌╌╌╌╌╌╌┤
-        │  both │
-        └───────┘
+        shape: (2, 1)
+        ┌────────┐
+        │ foo    │
+        │ ---    │
+        │ str    │
+        ╞════════╡
+        │  hello │
+        ├╌╌╌╌╌╌╌╌┤
+        │ world  │
+        └────────┘
+
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> df.select(pl.col("foo").str.rstrip("wod\t"))
+        shape: (2, 1)
+        ┌─────────┐
+        │ foo     │
+        │ ---     │
+        │ str     │
+        ╞═════════╡
+        │  hello  │
+        ├╌╌╌╌╌╌╌╌╌┤
+        │ worl    │
+        └─────────┘
 
         """
-        if matches is not None and len(matches) > 1:
-            raise ValueError("matches should contain a single character")
         return pli.wrap_expr(self._pyexpr.str_rstrip(matches))
 
     def zfill(self, alignment: int) -> pli.Expr:
@@ -663,7 +707,7 @@ class ExprStringNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.str_json_path_match(json_path))
 
-    def decode(self, encoding: TransferEncoding, strict: bool = False) -> pli.Expr:
+    def decode(self, encoding: TransferEncoding) -> pli.Expr:
         """
         Decode a value using the provided encoding.
 
@@ -671,34 +715,12 @@ class ExprStringNameSpace:
         ----------
         encoding : {'hex', 'base64'}
             The encoding to use.
-        strict
-            How to handle invalid inputs:
-
-            - ``True``: An error will be thrown if unable to decode a value.
-            - ``False``: Unhandled values will be replaced with `None`.
-
-        Examples
-        --------
-        >>> df = pl.DataFrame({"encoded": ["666f6f", "626172", None]})
-        >>> df.select(pl.col("encoded").str.decode("hex"))
-        shape: (3, 1)
-        ┌─────────┐
-        │ encoded │
-        │ ---     │
-        │ str     │
-        ╞═════════╡
-        │ foo     │
-        ├╌╌╌╌╌╌╌╌╌┤
-        │ bar     │
-        ├╌╌╌╌╌╌╌╌╌┤
-        │ null    │
-        └─────────┘
 
         """
         if encoding == "hex":
-            return pli.wrap_expr(self._pyexpr.str_hex_decode(strict))
+            return pli.wrap_expr(self._pyexpr.str_hex_decode())
         elif encoding == "base64":
-            return pli.wrap_expr(self._pyexpr.str_base64_decode(strict))
+            return pli.wrap_expr(self._pyexpr.str_base64_decode())
         else:
             raise ValueError(
                 f"encoding must be one of {{'hex', 'base64'}}, got {encoding}"
