@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 import polars.internals as pli
-from polars.datatypes import TemporalDataType
+from polars.datatypes import PolarsTemporalType
 from polars.internals.series.utils import expr_dispatch
 from polars.utils import deprecated_alias
 
@@ -23,7 +23,7 @@ class StringNameSpace:
 
     def strptime(
         self,
-        datatype: TemporalDataType,
+        datatype: PolarsTemporalType,
         fmt: str | None = None,
         strict: bool = True,
         exact: bool = True,
@@ -269,7 +269,7 @@ class StringNameSpace:
 
         """
 
-    def decode(self, encoding: TransferEncoding, strict: bool = False) -> pli.Series:
+    def decode(self, encoding: TransferEncoding) -> pli.Series:
         """
         Decode a value using the provided encoding.
 
@@ -277,23 +277,6 @@ class StringNameSpace:
         ----------
         encoding : {'hex', 'base64'}
             The encoding to use.
-        strict
-            How to handle invalid inputs:
-
-            - ``True``: An error will be thrown if unable to decode a value.
-            - ``False``: Unhandled values will be replaced with `None`.
-
-        Examples
-        --------
-        >>> s = pl.Series(["666f6f", "626172", None])
-        >>> s.str.decode("hex")
-        shape: (3,)
-        Series: '' [str]
-        [
-            "foo"
-            "bar"
-            null
-        ]
 
         """
 
@@ -666,36 +649,108 @@ class StringNameSpace:
 
         """
 
-    def strip(self, matches: None | str = None) -> pli.Series:
-        """
-        Remove leading and trailing whitespace.
+    def strip(self, matches: str | None = None) -> pli.Series:
+        r"""
+        Remove leading and trailing characters.
 
         Parameters
         ----------
         matches
-            An optional single character that should be trimmed
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
+
+        Examples
+        --------
+        >>> s = pl.Series([" hello ", "\tworld"])
+        >>> s.str.strip()
+        shape: (2,)
+        Series: '' [str]
+        [
+                "hello"
+                "world"
+        ]
+
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> s.str.strip("od\t")
+        shape: (2,)
+        Series: '' [str]
+        [
+                " hello "
+                "worl"
+        ]
 
         """
 
-    def lstrip(self, matches: None | str = None) -> pli.Series:
-        """
-        Remove leading whitespace.
+    def lstrip(self, matches: str | None = None) -> pli.Series:
+        r"""
+        Remove leading characters.
 
         Parameters
         ----------
         matches
-            An optional single character that should be trimmed
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
+
+        Examples
+        --------
+        >>> s = pl.Series([" hello ", "\tworld"])
+        >>> s.str.lstrip()
+        shape: (2,)
+        Series: '' [str]
+        [
+                "hello "
+                "world"
+        ]
+
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> s.str.lstrip("wod\t")
+        shape: (2,)
+        Series: '' [str]
+        [
+                " hello "
+                "rld"
+        ]
 
         """
 
-    def rstrip(self, matches: None | str = None) -> pli.Series:
-        """
-        Remove trailing whitespace.
+    def rstrip(self, matches: str | None = None) -> pli.Series:
+        r"""
+        Remove trailing characters.
 
         Parameters
         ----------
         matches
-            An optional single character that should be trimmed
+            The set of characters to be removed. All combinations of this set of
+            characters will be stripped. If set to None (default), all whitespace is
+            removed instead.
+
+        Examples
+        --------
+        >>> s = pl.Series([" hello ", "world\t"])
+        >>> s.str.rstrip()
+        shape: (2,)
+        Series: '' [str]
+        [
+                " hello"
+                "world"
+        ]
+
+        Characters can be stripped by passing a string as argument. Note that whitespace
+        will not be stripped automatically when doing so.
+
+        >>> s.str.rstrip("wod\t")
+        shape: (2,)
+        Series: '' [str]
+        [
+                " hello "
+                "worl"
+        ]
 
         """
 
