@@ -16,7 +16,7 @@ else:
     from backports import zoneinfo
 
 import polars as pl
-from polars.datatypes import DTYPE_TEMPORAL_UNITS, TemporalDataType
+from polars.datatypes import DTYPE_TEMPORAL_UNITS, PolarsTemporalType
 from polars.testing import assert_frame_equal, assert_series_equal
 from polars.testing._private import verify_series_and_expr_api
 
@@ -581,6 +581,50 @@ def test_date_range_lazy() -> None:
         )
     ]
 
+    assert pl.DataFrame(
+        {
+            "start": [date(2000, 1, 1), date(2022, 6, 1)],
+            "stop": [date(2000, 1, 2), date(2022, 6, 2)],
+        }
+    ).with_columns(
+        pl.date_range(
+            pl.col("start"),
+            pl.col("stop"),
+            interval="1d",
+        ).alias("dts")
+    ).to_dict(
+        False
+    ) == {
+        "start": [date(2000, 1, 1), date(2022, 6, 1)],
+        "stop": [date(2000, 1, 2), date(2022, 6, 2)],
+        "dts": [
+            [date(2000, 1, 1), date(2000, 1, 2)],
+            [date(2022, 6, 1), date(2022, 6, 2)],
+        ],
+    }
+
+    assert pl.DataFrame(
+        {
+            "start": [datetime(2000, 1, 1), datetime(2022, 6, 1)],
+            "stop": [datetime(2000, 1, 2), datetime(2022, 6, 2)],
+        }
+    ).with_columns(
+        pl.date_range(
+            pl.col("start"),
+            pl.col("stop"),
+            interval="1d",
+        ).alias("dts")
+    ).to_dict(
+        False
+    ) == {
+        "start": [datetime(2000, 1, 1, 0, 0), datetime(2022, 6, 1, 0, 0)],
+        "stop": [datetime(2000, 1, 2, 0, 0), datetime(2022, 6, 2, 0, 0)],
+        "dts": [
+            [datetime(2000, 1, 1, 0, 0), datetime(2000, 1, 2, 0, 0)],
+            [datetime(2022, 6, 1, 0, 0), datetime(2022, 6, 2, 0, 0)],
+        ],
+    }
+
 
 @pytest.mark.parametrize(
     "one,two",
@@ -593,7 +637,7 @@ def test_date_range_lazy() -> None:
         (date(5001, 1, 1), date(5001, 1, 2)),
     ],
 )
-def test_date_comp(one: TemporalDataType, two: TemporalDataType) -> None:
+def test_date_comp(one: PolarsTemporalType, two: PolarsTemporalType) -> None:
     a = pl.Series("a", [one, two])
     assert (a == one).to_list() == [True, False]
     assert (a == two).to_list() == [False, True]
@@ -958,15 +1002,91 @@ def test_asof_join_tolerance_grouper() -> None:
     assert out.frame_equal(expected)
 
 
-def test_duration_function() -> None:
+def test_datetime_duration_offset() -> None:
+    df = pl.DataFrame(
+        {
+            "datetime": [
+                datetime(1999, 1, 1, 7),
+                datetime(2022, 1, 2, 14),
+                datetime(3000, 12, 31, 21),
+            ],
+            "add": [1, 2, -1],
+        }
+    )
+    out = df.select(
+        [
+            (pl.col("datetime") + pl.duration(weeks="add")).alias("add_weeks"),
+            (pl.col("datetime") + pl.duration(days="add")).alias("add_days"),
+            (pl.col("datetime") + pl.duration(hours="add")).alias("add_hours"),
+            (pl.col("datetime") + pl.duration(seconds="add")).alias("add_seconds"),
+            (pl.col("datetime") + pl.duration(microseconds=pl.col("add") * 1000)).alias(
+                "add_usecs"
+            ),
+        ]
+    )
+    expected = pl.DataFrame(
+        {
+            "add_weeks": [
+                datetime(1999, 1, 8, 7),
+                datetime(2022, 1, 16, 14),
+                datetime(3000, 12, 24, 21),
+            ],
+            "add_days": [
+                datetime(1999, 1, 2, 7),
+                datetime(2022, 1, 4, 14),
+                datetime(3000, 12, 30, 21),
+            ],
+            "add_hours": [
+                datetime(1999, 1, 1, hour=8),
+                datetime(2022, 1, 2, hour=16),
+                datetime(3000, 12, 31, hour=20),
+            ],
+            "add_seconds": [
+                datetime(1999, 1, 1, 7, second=1),
+                datetime(2022, 1, 2, 14, second=2),
+                datetime(3000, 12, 31, 20, 59, 59),
+            ],
+            "add_usecs": [
+                datetime(1999, 1, 1, 7, microsecond=1000),
+                datetime(2022, 1, 2, 14, microsecond=2000),
+                datetime(3000, 12, 31, 20, 59, 59, 999000),
+            ],
+        }
+    )
+    assert out.frame_equal(expected)
+
+
+def test_date_duration_offset() -> None:
+    df = pl.DataFrame(
+        {
+            "date": [date(10, 1, 1), date(2000, 7, 5), date(9990, 12, 31)],
+            "offset": [365, 7, -31],
+        }
+    )
+    out = df.select(
+        [
+            (pl.col("date") + pl.duration(days="offset")).alias("add_days"),
+            (pl.col("date") - pl.duration(days="offset")).alias("sub_days"),
+            (pl.col("date") + pl.duration(weeks="offset")).alias("add_weeks"),
+            (pl.col("date") - pl.duration(weeks="offset")).alias("sub_weeks"),
+        ]
+    )
+    assert out.to_dict(False) == {
+        "add_days": [date(11, 1, 1), date(2000, 7, 12), date(9990, 11, 30)],
+        "sub_days": [date(9, 1, 1), date(2000, 6, 28), date(9991, 1, 31)],
+        "add_weeks": [date(16, 12, 30), date(2000, 8, 23), date(9990, 5, 28)],
+        "sub_weeks": [date(3, 1, 3), date(2000, 5, 17), date(9991, 8, 5)],
+    }
+
+
+def test_add_duration_3786() -> None:
     df = pl.DataFrame(
         {
             "datetime": [datetime(2022, 1, 1), datetime(2022, 1, 2)],
             "add": [1, 2],
         }
     )
-
-    out = df.select(
+    assert df.slice(0, 1).with_columns(
         [
             (pl.col("datetime") + pl.duration(weeks="add")).alias("add_weeks"),
             (pl.col("datetime") + pl.duration(days="add")).alias("add_days"),
@@ -976,25 +1096,15 @@ def test_duration_function() -> None:
             ),
             (pl.col("datetime") + pl.duration(hours="add")).alias("add_hours"),
         ]
-    )
-
-    expected = pl.DataFrame(
-        {
-            "add_weeks": [datetime(2022, 1, 8), datetime(2022, 1, 16)],
-            "add_days": [datetime(2022, 1, 2), datetime(2022, 1, 4)],
-            "add_seconds": [
-                datetime(2022, 1, 1, second=1),
-                datetime(2022, 1, 2, second=2),
-            ],
-            "add_milliseconds": [
-                datetime(2022, 1, 1, microsecond=1000),
-                datetime(2022, 1, 2, microsecond=2000),
-            ],
-            "add_hours": [datetime(2022, 1, 1, hour=1), datetime(2022, 1, 2, hour=2)],
-        }
-    )
-
-    assert out.frame_equal(expected)
+    ).to_dict(False) == {
+        "datetime": [datetime(2022, 1, 1, 0, 0)],
+        "add": [1],
+        "add_weeks": [datetime(2022, 1, 8, 0, 0)],
+        "add_days": [datetime(2022, 1, 2, 0, 0)],
+        "add_seconds": [datetime(2022, 1, 1, 0, 0, 1)],
+        "add_milliseconds": [datetime(2022, 1, 1, 0, 0, 0, 1000)],
+        "add_hours": [datetime(2022, 1, 1, 1, 0)],
+    }
 
 
 def test_rolling_groupby_by_argument() -> None:
@@ -1475,34 +1585,6 @@ def test_groupby_rolling_by_ordering() -> None:
     }
 
 
-def test_add_duration_3786() -> None:
-    df = pl.DataFrame(
-        {
-            "datetime": [datetime(2022, 1, 1), datetime(2022, 1, 2)],
-            "add": [1, 2],
-        }
-    )
-    assert df.slice(0, 1).with_columns(
-        [
-            (pl.col("datetime") + pl.duration(weeks="add")).alias("add_weeks"),
-            (pl.col("datetime") + pl.duration(days="add")).alias("add_days"),
-            (pl.col("datetime") + pl.duration(seconds="add")).alias("add_seconds"),
-            (pl.col("datetime") + pl.duration(milliseconds="add")).alias(
-                "add_milliseconds"
-            ),
-            (pl.col("datetime") + pl.duration(hours="add")).alias("add_hours"),
-        ]
-    ).to_dict(False) == {
-        "datetime": [datetime(2022, 1, 1, 0, 0)],
-        "add": [1],
-        "add_weeks": [datetime(2022, 1, 8, 0, 0)],
-        "add_days": [datetime(2022, 1, 2, 0, 0)],
-        "add_seconds": [datetime(2022, 1, 1, 0, 0, 1)],
-        "add_milliseconds": [datetime(2022, 1, 1, 0, 0, 0, 1000)],
-        "add_hours": [datetime(2022, 1, 1, 1, 0)],
-    }
-
-
 def test_groupby_rolling_by_() -> None:
     df = pl.DataFrame({"group": pl.arange(0, 3, eager=True)}).join(
         pl.DataFrame(
@@ -2103,3 +2185,124 @@ def test_tz_aware_filter_lit() -> None:
             ),
         ],
     }
+
+
+def test_asof_join_by_forward() -> None:
+    dfa = pl.DataFrame(
+        {"category": ["a", "a", "a", "a", "a"], "value_one": [1, 2, 3, 5, 12]}
+    )
+
+    dfb = pl.DataFrame({"category": ["a"], "value_two": [3]})
+
+    assert dfa.join_asof(
+        dfb,
+        left_on="value_one",
+        right_on="value_two",
+        by="category",
+        strategy="forward",
+    ).to_dict(False) == {
+        "category": ["a", "a", "a", "a", "a"],
+        "value_one": [1, 2, 3, 5, 12],
+        "value_two": [3, 3, 3, None, None],
+    }
+
+
+def test_truncate_by_calendar_weeks() -> None:
+    # 5557
+    start = datetime(2022, 11, 14, 0, 0, 0)
+    end = datetime(2022, 11, 20, 0, 0, 0)
+
+    assert (
+        pl.date_range(start, end, timedelta(days=1), name="date")
+        .to_frame()
+        .select([pl.col("date").dt.truncate("1w")])
+    ).to_dict(False) == {
+        "date": [
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+            datetime(2022, 11, 14),
+        ],
+    }
+
+    df = pl.DataFrame(
+        {
+            "date": pl.Series(["1768-03-01", "2023-01-01"]).str.strptime(
+                pl.Date, "%Y-%m-%d"
+            )
+        }
+    )
+
+    assert df.select(pl.col("date").dt.truncate("1w")).to_dict(False) == {
+        "date": [
+            date(1768, 2, 29),
+            date(2022, 12, 26),
+        ],
+    }
+
+
+def test_truncate_by_multiple_weeks() -> None:
+    df = pl.DataFrame(
+        {
+            "date": pl.Series(
+                [
+                    # Wednesday and Monday
+                    "2022-04-20",
+                    "2022-11-28",
+                ]
+            ).str.strptime(pl.Date, "%Y-%m-%d")
+        }
+    )
+
+    assert (
+        df.select(
+            [
+                pl.col("date").dt.truncate("2w").alias("2w"),
+                pl.col("date").dt.truncate("3w").alias("3w"),
+                pl.col("date").dt.truncate("4w").alias("4w"),
+                pl.col("date").dt.truncate("5w").alias("5w"),
+                pl.col("date").dt.truncate("17w").alias("17w"),
+            ]
+        )
+    ).to_dict(False) == {
+        "2w": [date(2022, 4, 11), date(2022, 11, 21)],
+        "3w": [date(2022, 4, 4), date(2022, 11, 14)],
+        "4w": [date(2022, 3, 28), date(2022, 11, 7)],
+        "5w": [date(2022, 3, 21), date(2022, 10, 31)],
+        "17w": [date(2021, 12, 27), date(2022, 8, 8)],
+    }
+
+
+def test_round_by_week() -> None:
+    df = pl.DataFrame(
+        {
+            "date": pl.Series(
+                [
+                    # Sunday and Monday
+                    "1998-04-12",
+                    "2022-11-28",
+                ]
+            ).str.strptime(pl.Date, "%Y-%m-%d")
+        }
+    )
+
+    assert (
+        df.select(
+            [
+                pl.col("date").dt.round("7d").alias("7d"),
+                pl.col("date").dt.round("1w").alias("1w"),
+            ]
+        )
+    ).to_dict(False) == {
+        "7d": [date(1998, 4, 9), date(2022, 12, 1)],
+        "1w": [date(1998, 4, 13), date(2022, 11, 28)],
+    }
+
+
+def test_cast_time_to_duration() -> None:
+    assert pl.Series([time(hour=0, minute=0, second=2)]).cast(
+        pl.Duration
+    ).item() == timedelta(seconds=2)
