@@ -135,7 +135,7 @@ def test_getitem_errs() -> None:
     with pytest.raises(
         ValueError,
         match=r"Cannot __getitem__ on Series of dtype: "
-        r"'<class 'polars.datatypes.Int64'>' with argument: "
+        r"'Int64' with argument: "
         r"'{'strange'}' of type: '<class 'set'>'.",
     ):
         df["a"][{"strange"}]
@@ -301,3 +301,36 @@ def test_epoch_time_type() -> None:
         pl.ComputeError, match="Cannot compute timestamp of a series with dtype 'Time'"
     ):
         pl.Series([time(0, 0, 1)]).dt.epoch("s")
+
+
+def test_duplicate_columns_arg_csv() -> None:
+    f = io.BytesIO()
+    pl.DataFrame({"x": [1, 2, 3], "y": ["a", "b", "c"]}).write_csv(f)
+    f.seek(0)
+    with pytest.raises(
+        ValueError, match=r"'columns' arg should only have unique values"
+    ):
+        pl.read_csv(f, columns=["x", "x", "y"])
+
+
+def test_datetime_time_add_err() -> None:
+    with pytest.raises(pl.ComputeError):
+        pl.Series([datetime(1970, 1, 1, 0, 0, 1)]) + pl.Series([time(0, 0, 2)])
+
+
+@typing.no_type_check
+def test_invalid_dtype() -> None:
+    with pytest.raises(
+        ValueError,
+        match=r"Given dtype: 'mayonnaise' is not a valid Polars data type and cannot be converted into one",  # noqa: E501
+    ):
+        pl.Series([1, 2], dtype="mayonnaise")
+
+
+def test_arr_eval_named_cols() -> None:
+    df = pl.DataFrame({"A": ["a", "b"], "B": [["a", "b"], ["c", "d"]]})
+
+    with pytest.raises(
+        pl.ComputeError,
+    ):
+        df.select(pl.col("B").arr.eval(pl.element().append(pl.col("A"))))
