@@ -42,6 +42,7 @@ def test_cum_agg() -> None:
 
 
 def test_init_inputs(monkeypatch: Any) -> None:
+    nan = float("nan")
     for flag in [False, True]:
         monkeypatch.setattr(pl.internals.construction, "_PYARROW_AVAILABLE", flag)
         # Good inputs
@@ -71,11 +72,34 @@ def test_init_inputs(monkeypatch: Any) -> None:
         )
         assert pl.Series("a", [10000, 20000, 30000], dtype=pl.Time).dtype == pl.Time
 
-        # 2d numpy array
-        res = pl.Series(name="a", values=np.array([[1, 2], [3, 4]], dtype=np.int64))
-        assert res.dtype == pl.List(pl.Int64)
-        assert res[0].to_list() == [1, 2]
-        assert res[1].to_list() == [3, 4]
+        # 2d numpy array and/or list of 1d numpy arrays
+        for res in (
+            pl.Series(
+                name="a",
+                values=np.array([[1, 2], [3, nan]], dtype=np.float32),
+                nan_to_null=True,
+            ),
+            pl.Series(
+                name="a",
+                values=[
+                    np.array([1, 2], dtype=np.float32),
+                    np.array([3, nan], dtype=np.float32),
+                ],
+                nan_to_null=True,
+            ),
+            pl.Series(
+                name="a",
+                values=(
+                    np.ndarray((2,), np.float32, np.array([1, 2], dtype=np.float32)),
+                    np.ndarray((2,), np.float32, np.array([3, nan], dtype=np.float32)),
+                ),
+                nan_to_null=True,
+            ),
+        ):
+            assert res.dtype == pl.List(pl.Float32)
+            assert res[0].to_list() == [1.0, 2.0]
+            assert res[1].to_list() == [3.0, None]
+
         assert pl.Series(
             values=np.array([["foo", "bar"], ["foo2", "bar2"]])
         ).dtype == pl.List(pl.Utf8)
@@ -1764,7 +1788,7 @@ def test_str_encode() -> None:
 def test_str_decode() -> None:
     hex_encoded = pl.Series(["666f6f", "626172", None])
     base64_encoded = pl.Series(["Zm9v", "YmFy", None])
-    expected = pl.Series(["foo", "bar", None])
+    expected = pl.Series([b"foo", b"bar", None])
 
     verify_series_and_expr_api(hex_encoded, expected, "str.decode", "hex")
     verify_series_and_expr_api(base64_encoded, expected, "str.decode", "base64")
@@ -1773,9 +1797,9 @@ def test_str_decode() -> None:
 def test_str_decode_exception() -> None:
     s = pl.Series(["not a valid", "626172", None])
     with pytest.raises(Exception):
-        s.str.decode(encoding="hex", strict=True)
+        s.str.decode(encoding="hex")
     with pytest.raises(Exception):
-        s.str.decode(encoding="base64", strict=True)
+        s.str.decode(encoding="base64")
     with pytest.raises(ValueError):
         s.str.decode("utf8")  # type: ignore[arg-type]
 
@@ -1802,16 +1826,6 @@ def test_str_to_uppercase() -> None:
     verify_series_and_expr_api(s, expected, "str.to_uppercase")
 
 
-def test_str_rstrip() -> None:
-    s = pl.Series([" hello ", "world\t "])
-    expected = pl.Series([" hello", "world"])
-    assert_series_equal(s.str.rstrip(), expected)
-
-    s = pl.Series([" hello ", "world\t "])
-    expected = pl.Series([" hell", "world"])
-    assert_series_equal(s.str.rstrip().str.rstrip("o"), expected)
-
-
 def test_str_strip() -> None:
     s = pl.Series([" hello ", "world\t "])
     expected = pl.Series(["hello", "world"])
@@ -1820,14 +1834,46 @@ def test_str_strip() -> None:
     expected = pl.Series(["hello", "worl"])
     assert_series_equal(s.str.strip().str.strip("d"), expected)
 
+    expected = pl.Series(["ell", "rld\t"])
+    assert_series_equal(s.str.strip(" hwo"), expected)
+
 
 def test_str_lstrip() -> None:
     s = pl.Series([" hello ", "\t world"])
     expected = pl.Series(["hello ", "world"])
     assert_series_equal(s.str.lstrip(), expected)
+
     expected = pl.Series(["ello ", "world"])
     assert_series_equal(s.str.lstrip().str.lstrip("h"), expected)
 
+    expected = pl.Series(["ello ", "\t world"])
+    assert_series_equal(s.str.lstrip("hw "), expected)
+
+
+def test_str_rstrip() -> None:
+    s = pl.Series([" hello ", "world\t "])
+    expected = pl.Series([" hello", "world"])
+    assert_series_equal(s.str.rstrip(), expected)
+
+    expected = pl.Series([" hell", "world"])
+    assert_series_equal(s.str.rstrip().str.rstrip("o"), expected)
+
+    expected = pl.Series([" he", "wor"])
+    assert_series_equal(s.str.rstrip("odl \t"), expected)
+
+
+def test_str_strip_whitespace() -> None:
+    a = pl.Series("a", ["trailing  ", "  leading", "  both  "])
+
+    expected = pl.Series("a", ["trailing", "  leading", "  both"])
+    verify_series_and_expr_api(a, expected, "str.rstrip")
+
+    expected = pl.Series("a", ["trailing  ", "leading", "both  "])
+    verify_series_and_expr_api(a, expected, "str.lstrip")
+
+    expected = pl.Series("a", ["trailing", "leading", "both"])
+    verify_series_and_expr_api(a, expected, "str.strip")
+
 
 def test_str_strptime() -> None:
     s = pl.Series(["2020-01-01", "2020-02-02"])
@@ -2211,16 +2257,6 @@ def test_product() -> None:
     assert out is None
 
 
-def test_strip() -> None:
-    a = pl.Series("a", ["trailing  ", "  leading", "  both  "])
-    expected = pl.Series("a", ["trailing", "  leading", "  both"])
-    verify_series_and_expr_api(a, expected, "str.rstrip")
-    expected = pl.Series("a", ["trailing  ", "leading", "both  "])
-    verify_series_and_expr_api(a, expected, "str.lstrip")
-    expected = pl.Series("a", ["trailing", "leading", "both"])
-    verify_series_and_expr_api(a, expected, "str.strip")
-
-
 def test_ceil() -> None:
     a = pl.Series("a", [1.8, 1.2, 3.0])
     expected = pl.Series("a", [2.0, 2.0, 3.0])
@@ -2473,3 +2509,16 @@ def test_get_chunks() -> None:
     chunks = pl.concat([a, b], rechunk=False).get_chunks()
     assert chunks[0].series_equal(a)
     assert chunks[1].series_equal(b)
+
+
+def test_item() -> None:
+    s = pl.Series("a", [1])
+    assert s.item() == 1
+
+    with pytest.raises(ValueError):
+        s = pl.Series("a", [1, 2])
+        s.item()
+
+    with pytest.raises(ValueError):
+        s = pl.Series("a", [])
+        s.item()
